Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(65)

Unified Diff: pkg/dartino_compiler/lib/src/dartino_selector.dart

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/dartino_compiler/lib/src/dartino_selector.dart
diff --git a/pkg/fletchc/lib/src/fletch_selector.dart b/pkg/dartino_compiler/lib/src/dartino_selector.dart
similarity index 87%
rename from pkg/fletchc/lib/src/fletch_selector.dart
rename to pkg/dartino_compiler/lib/src/dartino_selector.dart
index 78a2e73ed4962a591db3d9590a5d9f24ee54ecb6..ef56e91940c8b66a9b96094d19f5ce8de8d85d2e 100644
--- a/pkg/fletchc/lib/src/fletch_selector.dart
+++ b/pkg/dartino_compiler/lib/src/dartino_selector.dart
@@ -2,7 +2,7 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE.md file.
-library fletchc.fletch_selector;
+library dartino_compiler.dartino_selector;
enum SelectorKind {
Method,
@@ -10,10 +10,10 @@ enum SelectorKind {
Setter,
}
-class FletchSelector {
+class DartinoSelector {
final int encodedSelector;
- const FletchSelector(this.encodedSelector);
+ const DartinoSelector(this.encodedSelector);
int get id => decodeId(encodedSelector);
@@ -25,7 +25,7 @@ class FletchSelector {
static const MAX_UNIQUE_SELECTORS = (1 << 22) - 1;
static const ID_SHIFT = 10;
// Encode a fletch selector. The result is a 32bit integer with the following
// layout (lower to higher):
// - 8 bit arity
// - 2 bit kind
@@ -25,7 +25,7 @@ class FletchSelector {
static const MAX_UNIQUE_SELECTORS = (1 << 22) - 1;
static const ID_SHIFT = 10;
- // Encode a fletch selector. The result is a 32bit integer with the following
+ // Encode a dartino selector. The result is a 32bit integer with the following
// layout (lower to higher):
// - 8 bit arity
« no previous file with comments | « pkg/dartino_compiler/lib/src/dartino_registry.dart ('k') | pkg/dartino_compiler/lib/src/dartino_system_builder.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698